@@ -512,7 +512,7 @@ show_browse_dialog (char **device_name)
 	gtk_container_set_border_width(GTK_CONTAINER(selector), 5);
 	gtk_widget_show(selector);
 	g_object_set(selector,
-		     "show-search", TRUE,
+		     "show-searching", TRUE,
 		     "show-device-category", TRUE,
 		     "show-device-type", TRUE,
 		     NULL);
